# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2020-01-14 15:47
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0005_auto_20191217_1301'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='customer',
            options={},
        ),
    ]
